MaseratiMc12 @ Sylv1 / SimBin 2004
//////////////////////////////////////////////////////////////////////////
//
// Conventions:
//
// +x = left
// +z = rear
// +y = up
// +pitch = nose up
// +yaw = nose right
// +roll = right
//
// [BODY]  - a rigid mass with mass and inertial properties
// [JOINT] - a ball joint constraining an offset of one body to an
//           offset of another body (eliminates 3 DOF)
// [HINGE] - a constraint restricting the relative rotations of two
//           bodies to be around a single axis (eliminates 2 DOF).
// [BAR]   - a constraint holding an offset of one body from an offset of
//           another body at a fixed distance (eliminates 1 DOF).
// [JOINT&HINGE] - both the joint and hinge constraints, forming the
//           conventional definition of a hinge (eliminates 5 DOF).
//
//////////////////////////////////////////////////////////////////////////

// Body including all rigidly attached parts (wings, barge boards, etc.)
[BODY]
name=body mass=(1190.0) inertia=(946.0,1036.0,190.5)
pos=(0.0,0.0,0.0) ori=(0.0,0.0,0.0)


// Front spindles
[BODY]
name=fl_spindle mass=(15.5) inertia=(0.0275,0.0260,0.0245)
pos=(0.74,0.0,-1.295) ori=(0.0,0.0,0.0)

[BODY]
name=fr_spindle mass=(15.5) inertia=(0.0275,0.0260,0.0245)
pos=(-0.740,0.0,-1.295) ori=(0.0,0.0,0.0)

// Front wheels
[BODY]
name=fl_wheel mass=(29.0) inertia=(1.292,0.714,0.724)
pos=(0.80,0.0,-1.295) ori=(0.0,0.0,0.0)

[BODY]
name=fr_wheel mass=(29.0) inertia=(1.292,0.714,0.724)
pos=(-0.80,0.0,-1.295) ori=(0.0,0.0,0.0)

// Rear spindles
[BODY]
name=rl_spindle mass=(17.0) inertia=(0.0275,0.0260,0.0245)
pos=(0.80,0.0,1.295) ori=(0.0,0.0,0.0)

[BODY]
name=rr_spindle mass=(17.0) inertia=(0.0275,0.0260,0.0245)
pos=(-0.80,0.0,1.295) ori=(0.0,0.0,0.0)

// Rear wheels (includes half of rear-axle)
[BODY]
name=rl_wheel mass=(26.0) inertia=(1.446,0.875,0.875)
pos=(0.84,0.0,1.295) ori=(0.0,0.0,0.0)

[BODY]
name=rr_wheel mass=(26.0) inertia=(1.446,0.875,0.875)
pos=(-0.84,0.0,1.295) ori=(0.0,0.0,0.0)

// Fuel in tank is not rigidly attached - it is attached with springs and
// dampers to simulate movement.  Properties are defined in the HDV file.

[BODY]
name=fuel_tank mass=(4.0) inertia=(1.0,1.0,1.0)
pos=(0.0,0.0,0.0) ori=(0.0,0.0,0.0)

// Driver's head is not rigidly attached, and it does NOT affect the vehicle
// physics.  Position is from the eyepoint defined in the VEH file, while
// other properties are defined in the head physics file.

[BODY]
name=driver_head mass=(5.0) inertia=(0.02,0.02,0.02)
pos=(0.0,0.0,0.0) ori=(0.0,0.0,0.0)


//////////////////////////////////////////////////////////////////////////
//
// Constraints
//
//////////////////////////////////////////////////////////////////////////

// Front wheel and spindle connections
[JOINT&HINGE]
posbody=fl_wheel negbody=fl_spindle pos=fl_wheel axis=(-0.80,0.0,0.0)

[JOINT&HINGE]
posbody=fr_wheel negbody=fr_spindle pos=fr_wheel axis=(0.80,0.0,0.0)

// Front left suspension (2 A-arms + 1 steering arm = 5 links)
[BAR] // forward upper arm
name=fl_fore_upper posbody=body negbody=fl_spindle pos=(0.420,0.130,-1.295) neg=(0.723,0.160,-1.295)

[BAR] // rearward upper arm
posbody=body negbody=fl_spindle pos=(0.420,0.130,-1.095) neg=(0.723,0.160,-1.295)

[BAR] // forward lower arm
posbody=body negbody=fl_spindle pos=(0.227,-0.168,-1.295) neg=(0.760,-0.168,-1.295)

[BAR] // rearward lower arm
name=fl_fore_lower posbody=body negbody=fl_spindle pos=(0.227,-0.168,-1.045) neg=(0.760,-0.168,-1.295)

[BAR] // steering arm (must be named for identification)
name=fl_steering posbody=body negbody=fl_spindle pos=(0.255,-0.124,-1.435) neg=(0.752,-0.105,-1.435)

// Front right suspension (2 A-arms + 1 steering arm = 5 links)
[BAR] // forward upper arm (used in steering lock calculation)
name=fr_fore_upper posbody=body negbody=fr_spindle pos=(-0.420,0.130,-1.295) neg=(-0.723,0.160,-1.295)

[BAR] // rearward upper arm
posbody=body negbody=fr_spindle pos=(-0.420,0.130,-1.095) neg=(-0.723,0.160,-1.295)

[BAR] // forward lower arm
name=fr_fore_lower posbody=body negbody=fr_spindle pos=(-0.227,-0.168,-1.295) neg=(-0.760,-0.168,-1.295)

[BAR] // rearward lower arm
posbody=body negbody=fr_spindle pos=(-0.227,-0.168,-1.045) neg=(-0.760,-0.168,-1.295)

[BAR] // steering arm (must be named for identification)
name=fr_steering posbody=body negbody=fr_spindle pos=(-0.255,-0.124,-1.435) neg=(-0.752,-0.105,-1.435)

// Rear left suspension (2 A-arms + 1 straight link = 5 links)
[BAR] // forward upper arm
posbody=body negbody=rl_spindle pos=(0.543,0.160,0.995) neg=(0.795,0.188,1.295)

[BAR] // rearward upper arm
posbody=body negbody=rl_spindle pos=(0.543,0.160,1.345) neg=(0.795,0.188,1.295)

[BAR] // forward lower arm
posbody=body negbody=rl_spindle pos=(0.363,-0.152,0.995) neg=(0.823,-0.180,1.295)

[BAR] // rearward lower arm
posbody=body negbody=rl_spindle pos=(0.363,-0.152,1.345) neg=(0.823,-0.180,1.295)

[BAR] // straight link
posbody=body negbody=rl_spindle pos=(0.431,-0.00,1.465) neg=(0.819,0.008,1.465)

// Rear right suspension (2 A-arms + 1 straight link = 5 links)
[BAR] // forward upper arm
posbody=body negbody=rr_spindle pos=(-0.543,0.160,0.995) neg=(-0.795,0.188,1.295)

[BAR] // rearward upper arm
posbody=body negbody=rr_spindle pos=(-0.543,0.160,1.345) neg=(-0.795,0.188,1.295)

[BAR] // forward lower arm
posbody=body negbody=rr_spindle pos=(-0.363,-0.152,0.995) neg=(-0.823,-0.180,1.295)

[BAR] // rearward lower arm
posbody=body negbody=rr_spindle pos=(-0.363,-0.152,1.345) neg=(-0.823,-0.180,1.295)

[BAR] // straight link
posbody=body negbody=rr_spindle pos=(-0.431,-0.00,1.465) neg=(-0.819,0.008,1.465)

// Rear spindle and wheel connections
[JOINT&HINGE]
posbody=rl_wheel negbody=rl_spindle pos=rl_wheel axis=(-0.840,0.0,0.0)

[JOINT&HINGE]
posbody=rr_wheel negbody=rr_spindle pos=rr_wheel axis=(0.840,0.0,0.0)